votedperceptron
---------------

An implementation of the voted perceptron algorithm
described in the publication below:

::

    %0 Journal Article
    %D 1999
    %@ 0885-6125
    %J Machine Learning
    %V 37
    %N 3
    %R 10.1023/A:1007662407062
    %T Large Margin Classification Using the Perceptron Algorithm
    %U http://dx.doi.org/10.1023/A%3A1007662407062
    %I Kluwer Academic Publishers
    %8 1999-12-01
    %A Freund, Yoav
    %A Schapire, RobertE.
    %P 277-296
    %G English


Installation
~~~~~~~~~~~~

Install the `current PyPI release <https://pypi.python.org/pypi/votedperceptron>`_:

.. code:: bash

    pip install votedperceptron

Or install the development version from GitHub:

.. code:: bash

    pip install git+https://github.com/bmgee/votedperceptron

Usage
~~~~~

On `GitHub <https://github.com/bmgee/votedperceptron>`_ see ``examples/mnist_example.py`` for an MNIST digit classification example.

